==> App-CharmKit-0.20.tar.gz: App-CharmKit-0.20/lib/App/CharmKit/Role/Git.pm <==
package App::CharmKit::Role::Git;
$App::CharmKit::Role::Git::VERSION = '0.20';
# ABSTRACT: Checkout from git endpoints

use strict;
use warnings;
use Path::Tiny;
use Git::Repository;
use Class::Tiny {
    github => sub {'git@github.com'}
};


sub clone {
    my ($self, $location, $dst) = @_;
    my $cmd = ['clone', '-q'];
    if ($location =~ /^\w+\/\w+/) {
        $location = sprintf("%s:%s.git", $self->github, $location);
    }

    # Make sure dst exists, if not create the parent directories
    if (!$dst->exists) {
        $dst->mkpath;
    }

    Git::Repository->run(clone => $location, $dst, { quiet => 1 });
    printf("%s cloned to %s\n", $location, $dst->absolute);
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::CharmKit::Role::Git - Checkout from git endpoints

=head1 VERSION

version 0.20

=head1 METHODS

=head2 clone

clone repo from github or another git endpoint

=head1 AUTHOR

Adam Stokes <adamjs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Adam Stokes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
DAMAGES.

=cut

==> App-CharmKit-1.0.1.tar.gz: App-CharmKit-1.0.1/lib/App/CharmKit/Role/Git.pm <==
package App::CharmKit::Role::Git;
$App::CharmKit::Role::Git::VERSION = '1.0.1';
# ABSTRACT: Checkout from git endpoints

use strict;
use warnings;
use Path::Tiny;
use Git::Repository;
use Class::Tiny {
    github => sub {'git@github.com'}
};


sub clone {
    my ($self, $location, $dst) = @_;
    my $cmd = ['clone', '-q'];
    if ($location =~ /^\w+\/\w+/) {
        $location = sprintf("%s:%s.git", $self->github, $location);
    }

    # Make sure dst exists, if not create the parent directories
    if (!$dst->exists) {
        $dst->mkpath;
    }

    Git::Repository->run(clone => $location, $dst, { quiet => 1 });
    printf("%s cloned to %s\n", $location, $dst->absolute);
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::CharmKit::Role::Git - Checkout from git endpoints

=head1 VERSION

version 1.0.1

=head1 METHODS

=head2 clone

clone repo from github or another git endpoint

=head1 AUTHOR

Adam Stokes <adamjs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Adam Stokes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
DAMAGES.

=cut
